@@ -1,6 +1,6 @@
 package Test::Fixme;
 
-require 5.006002;
+require 5.006;
 use strict;
 use warnings;
 
@@ -14,7 +14,7 @@ our @ISA    = qw( Exporter  );
 our @EXPORT = qw( run_tests );
 
 # ABSTRACT: Check code for FIXMEs.
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.16'; # VERSION
 
 my $Test = Test::Builder->new;
 
@@ -25,6 +25,9 @@ sub run_tests {
     $args{match} = 'FIXME' unless defined $args{match} && length $args{match};
     $args{where} = '.'     unless defined $args{where} && length $args{where};
     $args{warn}  = 0       unless defined $args{warn}  && length $args{warn};
+    $args{format} = $ENV{TEST_FIXME_FORMAT} if defined $ENV{TEST_FIXME_FORMAT};
+    $args{format} = 'original'
+      unless defined $args{format} && $args{format} =~ /^(original|perl)$/;
     $args{filename_match} = qr/./
       unless defined $args{filename_match} && length $args{filename_match};
     my $first = 1;
@@ -48,7 +51,10 @@ sub run_tests {
         $Test->ok($ok || $args{warn}, "'$file'");
         next if $ok;
         $Test->diag('') if $first++;
-        $Test->diag(format_file_results($results));
+        $Test->diag(do {
+          no strict 'refs';
+          &{"format_file_results_$args{format}"}($results)
+        });
     }
 }
 
@@ -81,7 +87,7 @@ sub scan_file {
     return \@results;
 }
 
-sub format_file_results {
+sub format_file_results_original {
     my $results = shift;
     return undef unless defined $results;
 
@@ -102,6 +108,24 @@ sub format_file_results {
     return $out;
 }
 
+sub format_file_results_perl {
+    my $results = shift;
+    return undef unless defined $results;
+
+    my $out = '';
+
+    # format the results.
+    foreach my $result (@$results) {
+        my $file = ${$results}[0]->{file};
+        my $line = $$result{line};
+        my $text = $$result{text};
+        
+        $out .= "Pattern found at $file line $line:\n $text\n";
+    }
+
+    return $out;
+}
+
 sub list_files {
     my $path_arg = shift;
     croak
@@ -190,7 +214,7 @@ Test::Fixme - Check code for FIXMEs.
 
 =head1 VERSION
 
-version 0.14
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -267,6 +291,63 @@ Do not fail when a FIXME or other pattern is matched.  Tests that would
 have been failures will still issue a diagnostic that will be viewed
 when you run C<prove> without C<-v>, C<make test> or C<./Build test>.
 
+=item format
+
+Specifies format to be used for display of pattern matches.
+
+=over 4
+
+=item original
+
+The original and currently default format looks something like this:
+
+ # File: './lib/Test/Fixme.pm'
+ #     16      # ABSTRACT: Check code for FIXMEs.
+ #     25          $args{match} = 'FIXME' unless defined $args{match} && length $args{match};
+ #     28          $args{format} ||= $ENV{TEST_FIXME_FORMAT};
+ #     228      # FIXME - what about windows that are bigger than the screen?
+ #     230      # FIXME - add checking of user privileges here.
+ #     239     By default run_tests will search for 'FIXME' in all the files it can
+ #     280     Do not fail when a FIXME or other pattern is matched.  Tests that would
+ #     288     If you want to match something other than 'FIXME' then you may find
+ #     296      run_tests( skip_all => $ENV{SKIP_TEST_FIXME} );
+ #     303     L<Devel::FIXME>
+
+With the line numbers on the left and the offending text on the right.
+
+=item perl
+
+The "perl" format is that used by Perl itself to report warnings and errors.
+
+ # Pattern found at ./lib/Test/Fixme.pm line 16:
+ #  # ABSTRACT: Check code for FIXMEs.
+ # Pattern found at ./lib/Test/Fixme.pm line 25:
+ #      $args{match} = 'FIXME' unless defined $args{match} && length $args{match};
+ # Pattern found at ./lib/Test/Fixme.pm line 28:
+ #      $args{format} ||= $ENV{TEST_FIXME_FORMAT};
+ # Pattern found at ./lib/Test/Fixme.pm line 228:
+ #   # FIXME - what about windows that are bigger than the screen?
+ # Pattern found at ./lib/Test/Fixme.pm line 230:
+ #   # FIXME - add checking of user privileges here.
+ # Pattern found at ./lib/Test/Fixme.pm line 239:
+ #  By default run_tests will search for 'FIXME' in all the files it can
+ # Pattern found at ./lib/Test/Fixme.pm line 280:
+ #  Do not fail when a FIXME or other pattern is matched.  Tests that would
+ # Pattern found at ./lib/Test/Fixme.pm line 288:
+ #  If you want to match something other than 'FIXME' then you may find
+ # Pattern found at ./lib/Test/Fixme.pm line 296:
+ #   run_tests( skip_all => $ENV{SKIP_TEST_FIXME} );
+ # Pattern found at ./lib/Test/Fixme.pm line 303:
+ #  L<Devel::FIXME>
+
+For files that contain many offending patterns it may be a bit harder to read for
+humans, but easier to parse for IDEs.
+
+=back
+
+You may also use the C<TEST_FIXME_FORMAT> environment variable to override either
+the default or the value specified in the test file.
+
 =back
 
 =head1 HINTS
@@ -284,6 +365,13 @@ You may also wish to suppress the tests - try this:
 You can only run run_tests once per file. Please use several test
 files if you want to run several different tests.
 
+=head1 CAVEATS
+
+This module is fully supported back to Perl 5.8.1.  It may work on 5.8.0.  
+It should work on Perl 5.6.x and I may even test on 5.6.2.  I will accept
+patches to maintain compatibility for such older Perls, but you may
+need to fix it on 5.6.x / 5.8.0 and send me a patch.
+
 =head1 SEE ALSO
 
 L<Devel::FIXME>
@@ -295,19 +383,19 @@ list of several directories in the 'where' argument. Many thanks.
 
 =head1 AUTHOR
 
-original author: Edmund von der Burg
+Original author: Edmund von der Burg
 
-current maintainer: Graham Ollis <plicease@cpan.org>
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Dave O'Neill
 
-gregor herrmann <gregoa@debian.org>
+gregor herrmann E<lt>gregoa@debian.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Edmund von der Burg <evdb@ecclestoad.co.uk>, Graham Ollis <plicease@cpan.org>.
+This software is copyright (c) 2016 by Edmund von der Burg <evdb@ecclestoad.co.uk>, Graham Ollis <plicease@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -317,4 +405,4 @@ the same terms as the Perl 5 programming language system itself.
 __END__
 
 
-1;
\ No newline at end of file
+1;
